==> jc-1.4.0.tar.gz: javax/net/ssl/TrustManagerFactory.h <==
// public class javax.net.ssl.TrustManagerFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9d3f34fb2d30caf0 javax_net_ssl_TrustManagerFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_TrustManagerFactory_H_
#define _JC_javax_net_ssl_TrustManagerFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_KeyStore$object;
struct _jc_java_security_Provider$object;
struct _jc_javax_net_ssl_ManagerFactoryParameters$object;
struct _jc_javax_net_ssl_TrustManagerFactory$object;
struct _jc_javax_net_ssl_TrustManagerFactorySpi$object;

// Typedefs
typedef struct _jc_javax_net_ssl_TrustManagerFactory$sub_refs	_jc_javax_net_ssl_TrustManagerFactory$sub_refs;
typedef struct _jc_javax_net_ssl_TrustManagerFactory$sub_nonrefs	_jc_javax_net_ssl_TrustManagerFactory$sub_nonrefs;
typedef struct _jc_javax_net_ssl_TrustManagerFactory$refs	_jc_javax_net_ssl_TrustManagerFactory$refs;
typedef struct _jc_javax_net_ssl_TrustManagerFactory$nonrefs	_jc_javax_net_ssl_TrustManagerFactory$nonrefs;
typedef struct _jc_javax_net_ssl_TrustManagerFactory$object	_jc_javax_net_ssl_TrustManagerFactory$object;

typedef struct _jc_javax_net_ssl_TrustManagerFactory$fields_struct	_jc_javax_net_ssl_TrustManagerFactory$fields_struct;
typedef const struct _jc_javax_net_ssl_TrustManagerFactory$vmethods	_jc_javax_net_ssl_TrustManagerFactory$vmethods;
typedef const struct _jc_javax_net_ssl_TrustManagerFactory$vtable	_jc_javax_net_ssl_TrustManagerFactory$vtable;
typedef const struct _jc_javax_net_ssl_TrustManagerFactory$vtype	_jc_javax_net_ssl_TrustManagerFactory$vtype;

// Class fields structure
struct _jc_javax_net_ssl_TrustManagerFactory$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fALGORITHM;
	struct _jc_java_lang_String$object	*TRUST__5fMANAGER__5fFACTORY;
};
extern _jc_javax_net_ssl_TrustManagerFactory$fields_struct _jc_javax_net_ssl_TrustManagerFactory$class_fields;

// Constructors
extern void _jc_javax_net_ssl_TrustManagerFactory$method$_init$74612ebc7288eabd(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_java_security_Provider$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_net_ssl_TrustManagerFactory$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *);
extern struct _jc_java_security_Provider$object *_jc_javax_net_ssl_TrustManagerFactory$method$getProvider$e8f9c9fb14140d5a(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *);
extern _jc_object_array *_jc_javax_net_ssl_TrustManagerFactory$method$getTrustManagers$c0dff820e1d24e1b(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *);
extern void _jc_javax_net_ssl_TrustManagerFactory$method$init$b62367181ff9cc21(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_java_security_KeyStore$object *);
extern void _jc_javax_net_ssl_TrustManagerFactory$method$init$2cb4129406ef255f(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$getProvider$e8f9c9fb14140d5a;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$getTrustManagers$c0dff820e1d24e1b;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$init$b62367181ff9cc21;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$init$2cb4129406ef255f;

// Static methods
extern struct _jc_java_lang_String$object *_jc_javax_net_ssl_TrustManagerFactory$method$getDefaultAlgorithm$2a434a91fa4a7731(_jc_env *);
extern struct _jc_javax_net_ssl_TrustManagerFactory$object *_jc_javax_net_ssl_TrustManagerFactory$method$getInstance$934256f74581cafc(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_javax_net_ssl_TrustManagerFactory$object *_jc_javax_net_ssl_TrustManagerFactory$method$getInstance$814c53c737d2ea88(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern struct _jc_javax_net_ssl_TrustManagerFactory$object *_jc_javax_net_ssl_TrustManagerFactory$method$getInstance$5f98854a8073865a(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *);

// Virtual methods structure
struct _jc_javax_net_ssl_TrustManagerFactory$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *);
	struct _jc_java_security_Provider$object	*(*getProvider$e8f9c9fb14140d5a)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *);
	_jc_object_array	*(*getTrustManagers$c0dff820e1d24e1b)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *);
	void	(*init$b62367181ff9cc21)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_java_security_KeyStore$object *);
	void	(*init$2cb4129406ef255f)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_net_ssl_TrustManagerFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_TrustManagerFactory$vmethods	javax_net_ssl_TrustManagerFactory;
};

// Vtype
struct _jc_javax_net_ssl_TrustManagerFactory$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_TrustManagerFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_TrustManagerFactory$sub_refs {
	struct _jc_javax_net_ssl_TrustManagerFactorySpi$object	*tmfSpi;
	struct _jc_java_security_Provider$object	*provider;
	struct _jc_java_lang_String$object	*algorithm;
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_TrustManagerFactory$refs {
    _jc_javax_net_ssl_TrustManagerFactory$sub_refs	javax_net_ssl_TrustManagerFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_TrustManagerFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_TrustManagerFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_TrustManagerFactory$sub_nonrefs	javax_net_ssl_TrustManagerFactory;
};

// Object instance structure
struct _jc_javax_net_ssl_TrustManagerFactory$object {
	_jc_javax_net_ssl_TrustManagerFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_TrustManagerFactory$vtype	*vtype;
	_jc_javax_net_ssl_TrustManagerFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_TrustManagerFactory$vtype _jc_javax_net_ssl_TrustManagerFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_TrustManagerFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_TrustManagerFactory$class_object;

#endif	/* _JC_javax_net_ssl_TrustManagerFactory_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/TrustManagerFactory.h <==
// public class javax.net.ssl.TrustManagerFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9d3f34fb2d30caf0 javax_net_ssl_TrustManagerFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_TrustManagerFactory_H_
#define _JC_javax_net_ssl_TrustManagerFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_KeyStore$object;
struct _jc_java_security_Provider$object;
struct _jc_javax_net_ssl_ManagerFactoryParameters$object;
struct _jc_javax_net_ssl_TrustManagerFactory$object;
struct _jc_javax_net_ssl_TrustManagerFactorySpi$object;

// Typedefs
typedef struct _jc_javax_net_ssl_TrustManagerFactory$sub_refs	_jc_javax_net_ssl_TrustManagerFactory$sub_refs;
typedef struct _jc_javax_net_ssl_TrustManagerFactory$sub_nonrefs	_jc_javax_net_ssl_TrustManagerFactory$sub_nonrefs;
typedef struct _jc_javax_net_ssl_TrustManagerFactory$refs	_jc_javax_net_ssl_TrustManagerFactory$refs;
typedef struct _jc_javax_net_ssl_TrustManagerFactory$nonrefs	_jc_javax_net_ssl_TrustManagerFactory$nonrefs;
typedef struct _jc_javax_net_ssl_TrustManagerFactory$object	_jc_javax_net_ssl_TrustManagerFactory$object;

typedef struct _jc_javax_net_ssl_TrustManagerFactory$fields_struct	_jc_javax_net_ssl_TrustManagerFactory$fields_struct;
typedef const struct _jc_javax_net_ssl_TrustManagerFactory$vmethods	_jc_javax_net_ssl_TrustManagerFactory$vmethods;
typedef const struct _jc_javax_net_ssl_TrustManagerFactory$vtable	_jc_javax_net_ssl_TrustManagerFactory$vtable;
typedef const struct _jc_javax_net_ssl_TrustManagerFactory$vtype	_jc_javax_net_ssl_TrustManagerFactory$vtype;

// Class fields structure
struct _jc_javax_net_ssl_TrustManagerFactory$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fALGORITHM;
	struct _jc_java_lang_String$object	*TRUST__5fMANAGER__5fFACTORY;
};
extern _jc_javax_net_ssl_TrustManagerFactory$fields_struct _jc_javax_net_ssl_TrustManagerFactory$class_fields;

// Constructors
extern void _jc_javax_net_ssl_TrustManagerFactory$method$_init$74612ebc7288eabd(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_javax_net_ssl_TrustManagerFactorySpi$object *, struct _jc_java_security_Provider$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_net_ssl_TrustManagerFactory$method$getAlgorithm$19abbbc132b9063a(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_Provider$object *_jc_javax_net_ssl_TrustManagerFactory$method$getProvider$e8f9c9fb14140d5a(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_net_ssl_TrustManagerFactory$method$getTrustManagers$c0dff820e1d24e1b(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *) _JC_JCNI_ATTR;
extern void _jc_javax_net_ssl_TrustManagerFactory$method$init$b62367181ff9cc21(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_java_security_KeyStore$object *) _JC_JCNI_ATTR;
extern void _jc_javax_net_ssl_TrustManagerFactory$method$init$2cb4129406ef255f(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$getAlgorithm$19abbbc132b9063a;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$getProvider$e8f9c9fb14140d5a;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$getTrustManagers$c0dff820e1d24e1b;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$init$b62367181ff9cc21;
extern _jc_method _jc_javax_net_ssl_TrustManagerFactory$method_info$init$2cb4129406ef255f;

// Static methods
extern struct _jc_java_lang_String$object *_jc_javax_net_ssl_TrustManagerFactory$method$getDefaultAlgorithm$2a434a91fa4a7731(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_net_ssl_TrustManagerFactory$object *_jc_javax_net_ssl_TrustManagerFactory$method$getInstance$934256f74581cafc(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_net_ssl_TrustManagerFactory$object *_jc_javax_net_ssl_TrustManagerFactory$method$getInstance$814c53c737d2ea88(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_net_ssl_TrustManagerFactory$object *_jc_javax_net_ssl_TrustManagerFactory$method$getInstance$5f98854a8073865a(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_security_Provider$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_net_ssl_TrustManagerFactory$vmethods {
	struct _jc_java_lang_String$object	*(*getAlgorithm$19abbbc132b9063a)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_Provider$object	*(*getProvider$e8f9c9fb14140d5a)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getTrustManagers$c0dff820e1d24e1b)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *) _JC_JCNI_ATTR;
	void	(*init$b62367181ff9cc21)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_java_security_KeyStore$object *) _JC_JCNI_ATTR;
	void	(*init$2cb4129406ef255f)(_jc_env *, struct _jc_javax_net_ssl_TrustManagerFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_ssl_TrustManagerFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_TrustManagerFactory$vmethods	javax_net_ssl_TrustManagerFactory;
};

// Vtype
struct _jc_javax_net_ssl_TrustManagerFactory$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_TrustManagerFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_TrustManagerFactory$sub_refs {
	struct _jc_javax_net_ssl_TrustManagerFactorySpi$object	*tmfSpi;
	struct _jc_java_security_Provider$object	*provider;
	struct _jc_java_lang_String$object	*algorithm;
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_TrustManagerFactory$refs {
    _jc_javax_net_ssl_TrustManagerFactory$sub_refs	javax_net_ssl_TrustManagerFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_TrustManagerFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_TrustManagerFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_TrustManagerFactory$sub_nonrefs	javax_net_ssl_TrustManagerFactory;
};

// Object instance structure
struct _jc_javax_net_ssl_TrustManagerFactory$object {
	_jc_javax_net_ssl_TrustManagerFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_TrustManagerFactory$vtype	*vtype;
	_jc_javax_net_ssl_TrustManagerFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_TrustManagerFactory$vtype _jc_javax_net_ssl_TrustManagerFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_TrustManagerFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_TrustManagerFactory$class_object;

#endif	/* _JC_javax_net_ssl_TrustManagerFactory_H_ */
